@@ -3,16 +3,16 @@ from os import mkdir
 
 class downloader:
 	namedir = "Download"
-	def img(link, namedir=namedir):
+	def picture(link, namedir=namedir):
 		try:
 			mkdir(namedir)
 			name = link.split("/")[-1]
 			r = get(link, allow_redirects=True)
-			open(f"{namedir}/img-{name}", "wb").write(r.content)
+			open(f"{namedir}/picture-{name}", "wb").write(r.content)
 		except FileExistsError:
 			name = link.split("/")[-1]
 			r = get(link, allow_redirects=True)
-			open(f"{namedir}/img-{name}", "wb").write(r.content)
+			open(f"{namedir}/picture-{name}", "wb").write(r.content)
 	def code(link, namedir=namedir):
 		try:
 			mkdir(namedir)
